<template>
  <div class="member-rule">
    <div class="mr-8">消费</div>
    <el-input-number
      v-model="amountValue"
      v-bind="inputAttrs"
      @input="onAmountChange"
    ></el-input-number>
    <div class="mx-8">元等于</div>
    <el-input-number
      v-model="growthValue"
      v-bind="inputAttrs"
      @input="onGrowthChange"
    ></el-input-number>
    <div class="ml-8">成长值</div>
  </div>
</template>

<script>
import { t } from 'el-business'
import utils from 'el-business-utils'

export default {
  props: {
    value: {
      type: Array,
      default: () => [],
    },
  },
  rules(item) {
    const errorMsg = `${t('elBus.common.pleaseEnter')}${
      item.label ? item.label.replace(/:/g, '').replace(/：/g, '') : ''
    }`
    return [
      {
        required: true,
        message: errorMsg,
      },
      {
        validator: (rule, value, callback) => {
          if (
            Array.isArray(value) &&
            value.filter((i) => !utils.isTrueEmpty(i)).length === 2
          ) {
            callback()
          } else {
            callback(new Error(errorMsg))
          }
        },
      },
    ]
  },
  inputFormat(row, item) {
    if (
      Array.isArray(item.commonFormatProps) &&
      item.commonFormatProps.length === 2
    ) {
      const amount = item.commonFormatProps[0]
      const growth = item.commonFormatProps[1]
      if (amount in row || growth in row) {
        return [row[amount], row[growth]]
      }
    } else {
      console.warn('please set commonFormatProps')
    }
  },
  outputFormat(val, item) {
    if (
      Array.isArray(item.commonFormatProps) &&
      item.commonFormatProps.length === 2
    ) {
      const amount = item.commonFormatProps[0]
      const growth = item.commonFormatProps[1]
      return {
        [amount]: !utils.isTrueEmpty(val?.[0]) ? val[0] : null,
        [growth]: !utils.isTrueEmpty(val?.[1]) ? val[1] : null,
      }
    } else {
      console.warn('please set commonFormatProps')
    }
  },
  data() {
    return {
      amountValue: null,
      growthValue: null,
      inputAttrs: {
        precision: 0,
        min: 0,
        controls: false,
      },
    }
  },
  watch: {
    value: {
      immediate: true,
      handler(value) {
        value = value || []
        this.amountValue = value?.[0] || undefined
        this.growthValue = value?.[1] || undefined
      },
    },
  },
  methods: {
    onAmountChange(e) {
      const value = [e, this.growthValue]
      this.emitValue(value)
    },
    onGrowthChange(e) {
      const value = [this.amountValue, e]
      this.emitValue(value)
    },
    emitValue(value) {
      this.$emit('input', value)
      this.$emit('change', value)
    },
  },
}
</script>

<style lang="scss" scoped>
.member-rule {
  display: flex;
  align-items: center;
}
</style>
